function HR= LocWhittleRobinson(x);
% function HR= LocWhittleRobinson(x);
% Local Whittle approximation. Compute the Hurst parameter
% by using the local Whittle method 
% Details of the method are presented in:
% P.M. Robinson, 'Gaussian semi-parametric estimation of long-range dependence', 
% Annals of Statistics,  pp 1630--1655, 1995.
% 
% The function to be optimized is 
% R(d) = log(1/m \sum_{j=1}^m \lambda_j^{2d} I_j ) 
%                          - 2 d 1/m \sum_{i=1}^m \log(\lambda_j).
% 
% Syntax:
%        HR = LocWhittleRobinson(x);
% Input: x = observations
%      
% 				--> m = number of samples to compute the regression
%						= N/3%
% Output: HR= Hurst parameter       
% 
% The objective function is LocFun
%
% Author: E. Moulines - ENST - moulines@sig.enst.fr - 09/01/98.
%
%     + Bardet, 2008
%--------------------------------------------


x= x(:);
nx= length(x);              % number of sample
m = floor(0.3*nx);

X= fft(x);                  % discrete Fourier transform of the samples
I= 1/(2*pi*nx)*X.*conj(X);  % periodogram
I= real(I(2:m+1));   		 % retain the m first frquencies (avoiding the 0 frequency)
lambda= 2*pi*(1:m)'/nx;     % Fourier frequencies.

LocFun=inline('log(mean((lambda.^(2*d)).*I))-2*d*mean(log(lambda))','d','lambda','I');

%--------------------------------------------
%d= fmin('LocWhitFun',-0.5,2,[],lambda,I);
%d= fmin('LocFun',-0.5,0.5,[],lambda,I); %pour version precedente 
d= fminbnd(LocFun,-0.5,0.5,[],lambda,I);
%d= fminbnd('LocWhittleFunction',-0.5,0.5,[],lambda,I); %pour version 6 
HR=d+0.5;
%--------------------------------------------

